DownloadManager class

Constructors

DownloadManager({int? maxConcurrentTasks})
factory

Properties

dio ↔ Dio
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxConcurrentTasks ↔ int
getter/setter pair
runningTasks ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBatchDownloads(List<String> urls, String savedDir, dynamic thead, dynamic tbody) → Future<void>
addDownload(String url, String savedDir, dynamic thead, dynamic tbody) → Future<DownloadTask?>
cancelBatchDownloads(List<String> urls) → Future<void>
cancelDownload(String url) → Future<void>
createCallback(dynamic url, int partialFileLength) → void Function(int, int)
disposeNotifiers(DownloadTask task) → void
download(String url, String savePath, dynamic cancelToken, String thead, String tbody, {dynamic forceDownload = false}) → Future<void>
getAllDownloads() → List<DownloadTask>
getBatchDownloadProgress(List<String> urls) → ValueNotifier<double>
getBatchDownloads(List<String> urls) → List<DownloadTask?>
getDownload(String url) → DownloadTask?
getFileNameFromUrl(String url) → String
This function is used for get file name with extension from url
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseBatchDownloads(List<String> urls) → Future<void>
pauseDownload(String url) → Future<void>
removeDownload(String url) → Future<void>
resumeBatchDownloads(List<String> urls) → Future<void>
resumeDownload(String url) → Future<void>
setStatus(DownloadTask? task, DownloadStatus status) → void
showWithSmallImage(String thead, dynamic tbody, dynamic saveDir) → void
toString() → String
A string representation of this object.
inherited
whenBatchDownloadsComplete(List<String> urls, {Duration timeout = const Duration(hours: 2)}) → Future<List<DownloadTask?>?>
whenDownloadComplete(String url, {Duration timeout = const Duration(hours: 2)}) → Future<DownloadStatus>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

theadTf ↔ String
getter/setter pair

Constants

partialExtension → const String
tempExtension → const String