DownloadTask class

Constructors

DownloadTask(DownloadRequest request)

Properties

hashCode → int
The hash code for this object.
no setterinherited
progress ↔ ValueNotifier<double>
getter/setter pair
request → DownloadRequest
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ValueNotifier<DownloadStatus>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
whenDownloadComplete({Duration timeout = const Duration(hours: 2)}) → Future<DownloadStatus>

Operators

operator ==(Object other) → bool
The equality operator.
inherited